<?php

namespace Sob\SobJob\Policies;

use Litepie\User\Contracts\UserPolicy;
use Sob\SobJob\Models\TableTest;

class TableTestPolicy
{

    /**
     * Determine if the given user can view the table_test.
     *
     * @param UserPolicy $user
     * @param TableTest $table_test
     *
     * @return bool
     */
    public function view(UserPolicy $user, TableTest $table_test)
    {
        if ($user->canDo('sob-job.table_test.view') && $user->isAdmin()) {
            return true;
        }

        return $table_test->user_id == user_id() && $table_test->user_type == user_type();
    }

    /**
     * Determine if the given user can create a table_test.
     *
     * @param UserPolicy $user
     * @param TableTest $table_test
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('sob-job.table_test.create');
    }

    /**
     * Determine if the given user can update the given table_test.
     *
     * @param UserPolicy $user
     * @param TableTest $table_test
     *
     * @return bool
     */
    public function update(UserPolicy $user, TableTest $table_test)
    {
        if ($user->canDo('sob-job.table_test.edit') && $user->isAdmin()) {
            return true;
        }

        return $table_test->user_id == user_id() && $table_test->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given table_test.
     *
     * @param UserPolicy $user
     * @param TableTest $table_test
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, TableTest $table_test)
    {
        return $table_test->user_id == user_id() && $table_test->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given table_test.
     *
     * @param UserPolicy $user
     * @param TableTest $table_test
     *
     * @return bool
     */
    public function verify(UserPolicy $user, TableTest $table_test)
    {
        if ($user->canDo('sob-job.table_test.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given table_test.
     *
     * @param UserPolicy $user
     * @param TableTest $table_test
     *
     * @return bool
     */
    public function approve(UserPolicy $user, TableTest $table_test)
    {
        if ($user->canDo('sob-job.table_test.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
