<?php

namespace Sob\SobJob\Providers;

use Illuminate\Support\ServiceProvider;

class SobJobServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'sob-job');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'sob-job');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('sob.sob-job', function ($app) {
            return $this->app->make('Sob\SobJob\SobJob');
        });

                // Bind TableTest to repository
        $this->app->bind(
            'Sob\SobJob\Interfaces\TableTestRepositoryInterface',
            \Sob\SobJob\Repositories\Eloquent\TableTestRepository::class
        );

        $this->app->register(\Sob\SobJob\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Sob\SobJob\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['sob.sob-job'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('sob/sob-job.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/sob-job')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/sob-job')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
